@@ -1,14 +1,14 @@
 use crate::model::fuel_block::BlockHeight;
 use async_graphql::Enum;
 use fuel_asm::Word;
-use fuel_tx::{Address, Color};
+use fuel_tx::{Address, AssetId};
 use serde::{Deserialize, Serialize};
 
 #[derive(Debug, Clone, Serialize, Deserialize)]
 pub struct Coin {
     pub owner: Address,
     pub amount: Word,
-    pub color: Color,
+    pub asset_id: AssetId,
     pub maturity: BlockHeight,
     pub status: CoinStatus,
     pub block_created: BlockHeight,
