@@ -1,10 +1,9 @@
 use crate::database::Database;
-use crate::model::fuel_block::FuelBlock;
+use crate::model::fuel_block::FuelBlockDb;
 use crate::schema::block::Block;
 use crate::schema::scalars::U64;
 use async_graphql::{Context, Object};
 use fuel_storage::Storage;
-use fuel_tx::Bytes32;
 
 pub const DEFAULT_NAME: &str = "Fuel.testnet";
 
@@ -20,7 +19,7 @@ impl ChainInfo {
         let db = ctx.data_unchecked::<Database>().clone();
         let height = db.get_block_height()?.unwrap_or_default();
         let id = db.get_block_id(height)?.unwrap_or_default();
-        let block = Storage::<Bytes32, FuelBlock>::get(&db, &id)?.unwrap_or_default();
+        let block = Storage::<fuel_types::Bytes32, FuelBlockDb>::get(&db, &id)?.unwrap_or_default();
         Ok(Block(block.into_owned()))
     }
 
