@@ -1,7 +1,7 @@
 use crate::coin_query::{random_improve, SpendQueryElement};
 use crate::database::{Database, KvStoreError};
 use crate::model::coin::{Coin as CoinModel, CoinStatus};
-use crate::schema::scalars::{HexString256, U64};
+use crate::schema::scalars::{Address, AssetId, UtxoId, U64};
 use crate::state::IterDirection;
 use async_graphql::InputObject;
 use async_graphql::{
@@ -10,20 +10,17 @@ use async_graphql::{
 };
 use fuel_storage::Storage;
 use fuel_tx::consts::MAX_INPUTS;
-use fuel_tx::{Address, Color as FuelTxColor, UtxoId};
 use itertools::Itertools;
 
-use super::scalars::HexStringUtxoId;
-
-pub struct Coin(UtxoId, CoinModel);
+pub struct Coin(fuel_tx::UtxoId, CoinModel);
 
 #[Object]
 impl Coin {
-    async fn utxo_id(&self) -> HexStringUtxoId {
+    async fn utxo_id(&self) -> UtxoId {
         self.0.into()
     }
 
-    async fn owner(&self) -> HexString256 {
+    async fn owner(&self) -> Address {
         self.1.owner.into()
     }
 
@@ -31,8 +28,8 @@ impl Coin {
         self.1.amount.into()
     }
 
-    async fn color(&self) -> HexString256 {
-        self.1.color.into()
+    async fn asset_id(&self) -> AssetId {
+        self.1.asset_id.into()
     }
 
     async fn maturity(&self) -> U64 {
@@ -51,15 +48,15 @@ impl Coin {
 #[derive(InputObject)]
 struct CoinFilterInput {
     /// address of the owner
-    owner: HexString256,
-    /// color of the coins
-    color: Option<HexString256>,
+    owner: Address,
+    /// asset ID of the coins
+    asset_id: Option<AssetId>,
 }
 
 #[derive(InputObject)]
 struct SpendQueryElementInput {
-    /// color of the coins
-    color: HexString256,
+    /// asset ID of the coins
+    asset_id: AssetId,
     /// address of the owner
     amount: U64,
 }
@@ -72,11 +69,11 @@ impl CoinQuery {
     async fn coin(
         &self,
         ctx: &Context<'_>,
-        #[graphql(desc = "utxo_id of the coin")] utxo_id: HexStringUtxoId,
+        #[graphql(desc = "utxo_id of the coin")] utxo_id: UtxoId,
     ) -> async_graphql::Result<Option<Coin>> {
         let utxo_id = utxo_id.0;
         let db = ctx.data_unchecked::<Database>().clone();
-        let block = Storage::<UtxoId, CoinModel>::get(&db, &utxo_id)?
+        let block = Storage::<fuel_tx::UtxoId, CoinModel>::get(&db, &utxo_id)?
             .map(|coin| Coin(utxo_id, coin.into_owned()));
         Ok(block)
     }
@@ -84,12 +81,12 @@ impl CoinQuery {
     async fn coins(
         &self,
         ctx: &Context<'_>,
-        after: Option<String>,
-        before: Option<String>,
-        first: Option<i32>,
-        last: Option<i32>,
         filter: CoinFilterInput,
-    ) -> async_graphql::Result<Connection<HexStringUtxoId, Coin, EmptyFields, EmptyFields>> {
+        first: Option<i32>,
+        after: Option<String>,
+        last: Option<i32>,
+        before: Option<String>,
+    ) -> async_graphql::Result<Connection<UtxoId, Coin, EmptyFields, EmptyFields>> {
         let db = ctx.data_unchecked::<Database>();
 
         query(
@@ -97,7 +94,7 @@ impl CoinQuery {
             before,
             first,
             last,
-            |after: Option<HexStringUtxoId>, before: Option<HexStringUtxoId>, first, last| async move {
+            |after: Option<UtxoId>, before: Option<UtxoId>, first, last| async move {
                 let (records_to_fetch, direction) = if let Some(first) = first {
                     (first, IterDirection::Forward)
                 } else if let Some(last) = last {
@@ -106,8 +103,8 @@ impl CoinQuery {
                     (0, IterDirection::Forward)
                 };
 
-                let after = after.map(UtxoId::from);
-                let before = before.map(UtxoId::from);
+                let after = after.map(fuel_tx::UtxoId::from);
+                let before = before.map(fuel_tx::UtxoId::from);
 
                 let start;
                 let end;
@@ -120,7 +117,7 @@ impl CoinQuery {
                     end = after;
                 }
 
-                let owner: Address = filter.owner.into();
+                let owner: fuel_tx::Address = filter.owner.into();
 
                 let mut coin_ids = db.owned_coins(owner, start, Some(direction));
                 let mut started = None;
@@ -141,7 +138,7 @@ impl CoinQuery {
                         true
                     })
                     .take(records_to_fetch);
-                let mut coins: Vec<UtxoId> = coins.try_collect()?;
+                let mut coins: Vec<fuel_tx::UtxoId> = coins.try_collect()?;
                 if direction == IterDirection::Reverse {
                     coins.reverse();
                 }
@@ -150,17 +147,17 @@ impl CoinQuery {
                 let coins: Vec<Coin> = coins
                     .into_iter()
                     .map(|id| {
-                        Storage::<UtxoId, CoinModel>::get(db, &id)
+                        Storage::<fuel_tx::UtxoId, CoinModel>::get(db, &id)
                             .transpose()
                             .ok_or(KvStoreError::NotFound)?
                             .map(|coin| Coin(id, coin.into_owned()))
                     })
                     .try_collect()?;
 
-                // filter coins by color
+                // filter coins by asset ID
                 let mut coins = coins;
-                if let Some(color) = filter.color {
-                    coins.retain(|coin| coin.1.color == color.0.into());
+                if let Some(asset_id) = filter.asset_id {
+                    coins.retain(|coin| coin.1.asset_id == asset_id.0);
                 }
 
                 // filter coins by status
@@ -171,7 +168,7 @@ impl CoinQuery {
                 connection.append(
                     coins
                         .into_iter()
-                        .map(|item| Edge::new(HexStringUtxoId::from(item.0), item)),
+                        .map(|item| Edge::new(UtxoId::from(item.0), item)),
                 );
                 Ok(connection)
             },
@@ -182,16 +179,16 @@ impl CoinQuery {
     async fn coins_to_spend(
         &self,
         ctx: &Context<'_>,
-        #[graphql(desc = "The Address of the utxo owner")] owner: HexString256,
+        #[graphql(desc = "The Address of the utxo owner")] owner: Address,
         #[graphql(desc = "The total amount of each asset type to spend")] spend_query: Vec<
             SpendQueryElementInput,
         >,
         #[graphql(desc = "The max number of utxos that can be used")] max_inputs: Option<u8>,
     ) -> async_graphql::Result<Vec<Coin>> {
-        let owner: Address = owner.0.into();
+        let owner: fuel_tx::Address = owner.0;
         let spend_query: Vec<SpendQueryElement> = spend_query
             .iter()
-            .map(|e| (owner, FuelTxColor::from(e.color.0), e.amount.0))
+            .map(|e| (owner, e.asset_id.0, e.amount.0))
             .collect();
         let max_inputs: u8 = max_inputs.unwrap_or(MAX_INPUTS);
 
